@@ -36,9 +36,14 @@ class Experimento:
         self.lista_de_indices_para_subsucesiones = None
         self.lista_ordenada_de_indices_mas_altos = None
         self.archivo_consecuencias = False
+
+        self.config_graficas = ConfigGraficas()
+
         self.entropias = dict()
         self.histogramas = dict()
 
+        self.config_graficas = m_cg.ConfigGrafica()
+
         nombre_recortado = pathlib.Path(self.nombre_archivo)
         try:
             dataframe_a_recortar = pd.DataFrame(pd.read_csv(self.nombre_archivo,
@@ -223,11 +228,9 @@ class Experimento:
 
     def realiza_procesamiento_MOTUS(self):
         self.calcula_distancias()
-        self.calcula_distancia_promediada_con_objeto(objeto, intervalo)
         self.calcula_velocidades()
         self.calcula_velocidades_promediadas()
         self.calcula_regiones_cuadriculadas()
-        self.calcula_matrices_regiones_preferidas()
 
     def verifica_intervalo_tiempo(self):
         arreglo_tiempo = self.tiempo
@@ -281,20 +284,20 @@ class Experimento:
         self.dist_objeto_4 = ((objeto_4_x - posiciones_x) ** 2 + (objeto_4_y - posiciones_y) ** 2) ** 0.5
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                         categoria="dist_objeto_1",
-                                         serie=self.dist_objeto_1)
+                                           categoria="dist_objeto_1",
+                                           serie=self.dist_objeto_1)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                         categoria="dist_objeto_2",
-                                         serie=self.dist_objeto_2)
+                                           categoria="dist_objeto_2",
+                                           serie=self.dist_objeto_2)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                         categoria="dist_objeto_3",
-                                         serie=self.dist_objeto_3)
+                                           categoria="dist_objeto_3",
+                                           serie=self.dist_objeto_3)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                         categoria="dist_objeto_4",
-                                         serie=self.dist_objeto_4)
+                                           categoria="dist_objeto_4",
+                                           serie=self.dist_objeto_4)
 
         print("Distancias calculadas.")
 
@@ -314,6 +317,8 @@ class Experimento:
                                              ((posiciones_x.iloc[i] - posiciones_x.iloc[i - 1]) ** 2 +
                                               (posiciones_y.iloc[i] - posiciones_y.iloc[i - 1]) ** 2) ** (1 / 2)
 
+        print("Distancia total calculada")
+
     def calcula_distancia_promediada_con_objeto(self, objeto, intervalo):
         arreglo_elegido = []
         if objeto is 1:
@@ -536,13 +541,10 @@ class Experimento:
         self.matriz_cuadriculada_solo_regiones_no_preferidas = \
             np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
 
-
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones_no_preferidas",
                                        datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
 
-
-
     def obtener_indice_regiones_objeto(self):
         lista_objetos_relevantes = [self.objeto_relevante_1,
                                     self.objeto_relevante_2,
@@ -777,7 +779,6 @@ class Experimento:
         else:
             return False
 
-
     def genera_dataframe_de_datos(self):
         diccionario_csv = {'Sample no.': self.samples,
                            'Time': self.tiempo,
@@ -847,7 +848,7 @@ class Experimento:
         data = {'1': ['Objeto_1',
                       'Objeto_2',
                       'Objeto_3',
-                      'Objeto_4',],
+                      'Objeto_4', ],
                 '2': [self.cantidad_posiciones_volumen_1,
                       self.cantidad_posiciones_volumen_2,
                       self.cantidad_posiciones_volumen_3,
@@ -866,7 +867,11 @@ class Experimento:
         lim_inf_y = limites_y[0]
         lim_sup_y = limites_y[1]
 
-        objetos_seleccionados = config_grafica.regresa_config_grafica_distancias()
+        objetos_seleccionados, objeto_a_promediar, tamanio_intervalo_para_promedio = \
+            config_grafica.regresa_config_grafica_distancias()
+
+        print("Objetos a graficar: ", objetos_seleccionados)
+
         objeto_1_seleccionado = objetos_seleccionados[0]
         objeto_2_seleccionado = objetos_seleccionados[1]
         objeto_3_seleccionado = objetos_seleccionados[2]
@@ -1192,8 +1197,8 @@ class Experimento:
                 config_grafica.regresa_config_grafica_figuras()
 
             print("Tamaño_volumenes:", tamanio_volumenes)
-            print("Div_volumenes:",div_volumenes)
-            print("tipo_grafica_volumen:",tipo_grafica_volumen)
+            print("Div_volumenes:", div_volumenes)
+            print("tipo_grafica_volumen:", tipo_grafica_volumen)
             print("rot_grafica_3d", rot_grafica_3d)
 
             self.cantidad_posiciones_volumenes, self.radios_volumenes = \
