@@ -24,7 +24,7 @@ def modificar_arreglo_para_evitar_divergencia_infinita(datos):
     return nuevos_datos
 
 def calcula_divergencia_de_2_arreglos(pk, qk):
-    nuevo_qk = modificar_matriz_para_evitar_divergencia_infinita(qk)
+    nuevo_qk = modificar_arreglo_para_evitar_divergencia_infinita(qk)
     divergencia = st.entropy(pk, nuevo_qk)
     return divergencia
 
